RealtimeRunner

Struct RealtimeRunner 

pub struct RealtimeRunner<CS> { /* private fields */ }
A runner that executes the simulation in synchronization with real-world time.

This runner controls the execution timing of each tick based on the tick_unit_duration. Periods without active events or source firings are skipped, allowing for efficient CPU usage while ensuring the simulation progresses at the correct wall-clock speed.

Notes

  • To perform periodic processing (e.g., status monitoring), register a periodic Source that does nothing.
  • If the implementations of Model, Source, and Hook are deterministic, this runner guarantees deterministic real-time execution.

Implementations

Source

impl RealtimeRunner<AlwaysContinueStrategy>

pub fn new(tick_unit_duration: StdDuration) -> Self

Creates a new RealtimeRunner with the AlwaysContinueStrategy.

Arguments
  • tick_unit_duration - The real-world duration that corresponds to 1 tick.
Source

impl<CS> RealtimeRunner<CS>

pub fn new_with_continue_strategy( tick_unit_duration: StdDuration, continue_strategy: CS, ) -> Self

Creates a new RealtimeRunner with a specific ContinueStrategy.