StandardRunner

Struct StandardRunner 

pub struct StandardRunner<CS> { /* private fields */ }
A standard runner that processes events sequentially in the order they were fired.

This runner executes the core simulation cycle (Source phase, Event phase) in a deterministic, serial fashion. If the skippable option is enabled, the simulation skips time periods where no events occur, ensuring efficient utilization of computational resources.

Deterministic Execution

As long as the implementations of Model, Source, and Hook are deterministic, simulations executed through this runner will demonstrate reproducible, deterministic behavior.

Implementations

Source

impl StandardRunner<AlwaysContinueStrategy>

pub fn new(skippable: bool) -> Self

Creates a new StandardRunner using the default AlwaysContinueStrategy.

Source

impl<CS> StandardRunner<CS>

pub fn new_with_continue_strategy( skippable: bool, continue_strategy: CS, ) -> Self

Creates a new StandardRunner with a custom ContinueStrategy.