pub struct ParallelRunner<Command, CS> { /* private fields */ }Expand description
A runner that enables parallel event execution.
Events with a priority exceeding sync_priority_threshold are processed
synchronously on the main thread, while others are processed in parallel.
Implementations
Sourceimpl<Command> ParallelRunner<Command, AlwaysContinueStrategy>
impl<Command> ParallelRunner<Command, AlwaysContinueStrategy>
Sourcepub fn new(skippable: bool, sync_priority_threshold: EventPriority) -> Self
pub fn new(skippable: bool, sync_priority_threshold: EventPriority) -> Self
Creates a new ParallelRunner using the AlwaysContinueStrategy.
Arguments
skippable- Iftrue, the runner allows skipping empty ticks to optimize simulation time.sync_priority_threshold- Events with a priority greater than or equal to this threshold will be processed synchronously on the main thread.
Sourceimpl<Command, CS> ParallelRunner<Command, CS>
impl<Command, CS> ParallelRunner<Command, CS>
Sourcepub fn new_with_continue_strategy(
skippable: bool,
sync_priority_threshold: EventPriority,
continue_strategy: CS,
) -> Self
pub fn new_with_continue_strategy( skippable: bool, sync_priority_threshold: EventPriority, continue_strategy: CS, ) -> Self
Creates a new ParallelRunner with a custom ContinueStrategy.
Arguments
skippable- Iftrue, the runner allows skipping empty ticks to optimize simulation time.sync_priority_threshold- Events with a priority greater than or equal to this threshold will be processed synchronously on the main thread.continue_strategy- The specific strategy used to determine how the simulation handles micro-step transitions.